summaryrefslogtreecommitdiff
path: root/util-misc
diff options
context:
space:
mode:
authorJoe Orton <jorton@apache.org>2009-03-24 15:26:04 +0000
committerJoe Orton <jorton@apache.org>2009-03-24 15:26:04 +0000
commit194df6f9bd97a019d1c57f02fa68ea253231ed74 (patch)
tree47480d9f55c17dedb120d1af9216d901dca85cb4 /util-misc
parent58655d21e27f30d20e612b1bc2118ef14b6f7039 (diff)
downloadapr-194df6f9bd97a019d1c57f02fa68ea253231ed74.tar.gz
* Makefile.in, configure.in: s/APU/APR/ in DSO handling code.
Use default install prefix of $libdir/apr-$major/ * util-misc/apu_dso.c: Update likewise. git-svn-id: https://svn.apache.org/repos/asf/apr/apr/trunk@757845 13f79535-47bb-0310-9956-ffa450edef68
Diffstat (limited to 'util-misc')
-rw-r--r--util-misc/apu_dso.c16
1 files changed, 8 insertions, 8 deletions
diff --git a/util-misc/apu_dso.c b/util-misc/apu_dso.c
index 383c5157a..1cd42bdd0 100644
--- a/util-misc/apu_dso.c
+++ b/util-misc/apu_dso.c
@@ -31,7 +31,7 @@
#include "apu_internal.h"
#include "apu_version.h"
-#if APU_DSO_BUILD
+#if APR_DSO_BUILD
#if APR_HAS_THREADS
static apr_thread_mutex_t* mutex = NULL;
@@ -126,11 +126,11 @@ apr_status_t apu_dso_load(apr_dso_handle_t **dlhandleptr,
|| (apr_filepath_list_split(&paths, pathlist, pool) != APR_SUCCESS))
paths = apr_array_make(pool, 1, sizeof(char*));
-#if defined(APU_DSO_LIBDIR)
+#if defined(APR_DSO_LIBDIR)
/* Always search our prefix path, but on some platforms such as
* win32 this may be left undefined
*/
- (*((char **)apr_array_push(paths))) = APU_DSO_LIBDIR;
+ (*((char **)apr_array_push(paths))) = APR_DSO_LIBDIR;
#endif
for (i = 0; i < paths->nelts; ++i)
@@ -159,14 +159,14 @@ apr_status_t apu_dso_load(apr_dso_handle_t **dlhandleptr,
if (rv == APR_SUCCESS) { /* APR_EDSOOPEN */
break;
}
-#if defined(APU_DSO_LIBDIR)
+#if defined(APR_DSO_LIBDIR)
else if (i < paths->nelts - 1) {
#else
- else { /* No APU_DSO_LIBDIR to skip */
+ else { /* No APR_DSO_LIBDIR to skip */
#endif
/* try with apr-util-APU_MAJOR_VERSION appended */
eos = apr_cpystrn(eos,
- "apr-util-" APU_STRINGIFY(APU_MAJOR_VERSION) "/",
+ "apr-" APR_STRINGIFY(APR_MAJOR_VERSION) "/",
sizeof(path) - (eos - path));
apr_cpystrn(eos, module, sizeof(path) - (eos - path));
@@ -195,5 +195,5 @@ apr_status_t apu_dso_load(apr_dso_handle_t **dlhandleptr,
return rv;
}
-#endif /* APU_DSO_BUILD */
+#endif /* APR_DSO_BUILD */
@@ -159,14 +159,14 @@ apr_status_t apu_dso_load(apr_dso_handle_t **dlhandleptr,
#endif
- /* try with apr-util-APU_MAJOR_VERSION appended */
+ /* try with apr-APR_MAJOR_VERSION appended */
eos = apr_cpystrn(eos,